==> tora_2.0.0.orig.tar.gz: tora-2.0.0/src/tolistviewformatter.cpp <==

/* BEGIN_COMMON_COPYRIGHT_HEADER
 *
 * TOra - An Oracle Toolkit for DBA's and developers
 * 
 * Shared/mixed copyright is held throughout files in this product
 * 
 * Portions Copyright (C) 2000-2001 Underscore AB
 * Portions Copyright (C) 2003-2005 Quest Software, Inc.
 * Portions Copyright (C) 2004-2008 Numerous Other Contributors
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 * 
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries. 
 * 
 *      You may link this product with any GPL'd Qt library.
 * 
 * All trademarks belong to their respective owners.
 *
 * END_COMMON_COPYRIGHT_HEADER */

#include "tolistviewformatter.h"

toListViewFormatter::toListViewFormatter()
{
}

toListViewFormatter::~toListViewFormatter()
{
}

void toListViewFormatter::endLine(QString &output)
{
#ifdef Q_OS_WIN32
    output += "\r\n";
#else
    output += "\n";
#endif
}

QVector<int> toListViewFormatter::selectedList(
    const QModelIndexList &selected)
{

    QVector<int> ret;
    for (QList<QModelIndex>::const_iterator it = selected.begin();
            it != selected.end();
            it++)
    {

        ret.append((*it).row());
    }

    return ret;
}

==> tora_2.1.3.orig.tar.gz: tora-2.1.3/src/tolistviewformatter.cpp <==

/* BEGIN_COMMON_COPYRIGHT_HEADER
 *
 * TOra - An Oracle Toolkit for DBA's and developers
 * 
 * Shared/mixed copyright is held throughout files in this product
 * 
 * Portions Copyright (C) 2000-2001 Underscore AB
 * Portions Copyright (C) 2003-2005 Quest Software, Inc.
 * Portions Copyright (C) 2004-2008 Numerous Other Contributors
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation;  only version 2 of
 * the License is valid for this program.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 *      As a special exception, you have permission to link this program
 *      with the Oracle Client libraries and distribute executables, as long
 *      as you follow the requirements of the GNU GPL in regard to all of the
 *      software in the executable aside from Oracle client libraries.
 * 
 *      Specifically you are not permitted to link this program with the
 *      Qt/UNIX, Qt/Windows or Qt Non Commercial products of TrollTech.
 *      And you are not permitted to distribute binaries compiled against
 *      these libraries. 
 * 
 *      You may link this product with any GPL'd Qt library.
 * 
 * All trademarks belong to their respective owners.
 *
 * END_COMMON_COPYRIGHT_HEADER */

#include "tolistviewformatter.h"

toListViewFormatter::toListViewFormatter()
{
}

toListViewFormatter::~toListViewFormatter()
{
}

void toListViewFormatter::endLine(QString &output)
{
#ifdef Q_OS_WIN32
    output += "\r\n";
#else
    output += "\n";
#endif
}

QVector<int> toListViewFormatter::selectedRows(
    const QModelIndexList &selected)
{

    QVector<int> ret;
    for (QList<QModelIndex>::const_iterator it = selected.begin();
            it != selected.end();
            it++)
    {
		int r = (*it).row();
		if (!ret.contains(r))
			ret.append(r);
    }

    return ret;
}

QVector<int> toListViewFormatter::selectedColumns(
	const QModelIndexList &selected)
{
	QVector<int> ret;
        ret.append(0); // for later check for row headers
	for (QList<QModelIndex>::const_iterator it = selected.begin();
            it != selected.end();
            it++)
    {
		int c = (*it).column();
		if (!ret.contains(c))
			ret.append(c);
    }

    return ret;
}
